==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/CompressType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The compress operation element can be used to reduce the document size by compression. This modifies the document, so note that this can lead to the invalidation of existing signatures and archive formats. The compression can also be provided by the execution settings basically web service independent for the storage of documents.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for CompressType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="CompressType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <choice>
 *         <element name="compressObjects" type="{http://schema.webpdf.de/1.0/operation}CompressObjectsType" minOccurs="0"/>
 *       </choice>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CompressType", propOrder = {
    "compressObjects"
})
@XmlSeeAlso({
    CompressSettingsType.class
})
public class CompressType
    extends BaseToolboxType
{

    protected CompressObjectsType compressObjects;

    /**
     * Gets the value of the compressObjects property.
     * 
     * @return
     *     possible object is
     *     {@link CompressObjectsType }
     *     
     */
    public CompressObjectsType getCompressObjects() {
        return compressObjects;
    }

    /**
     * Sets the value of the compressObjects property.
     * 
     * @param value
     *     allowed object is
     *     {@link CompressObjectsType }
     *     
     */
    public void setCompressObjects(CompressObjectsType value) {
        this.compressObjects = value;
    }

    public boolean isSetCompressObjects() {
        return (this.compressObjects!= null);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/CompressType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The compress operation element can be used to reduce the document size by compression. This modifies the document, so note that this can lead to the invalidation of existing signatures and archive formats. The compression can also be provided by the execution settings basically web service independent for the storage of documents.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for CompressType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="CompressType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <choice>
 *         <element name="compressObjects" type="{http://schema.webpdf.de/1.0/operation}CompressObjectsType" minOccurs="0"/>
 *       </choice>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CompressType", propOrder = {
    "compressObjects"
})
@XmlSeeAlso({
    CompressSettingsType.class
})
public class CompressType
    extends BaseToolboxType
{

    protected CompressObjectsType compressObjects;

    /**
     * Gets the value of the compressObjects property.
     * 
     * @return
     *     possible object is
     *     {@link CompressObjectsType }
     *     
     */
    public CompressObjectsType getCompressObjects() {
        return compressObjects;
    }

    /**
     * Sets the value of the compressObjects property.
     * 
     * @param value
     *     allowed object is
     *     {@link CompressObjectsType }
     *     
     */
    public void setCompressObjects(CompressObjectsType value) {
        this.compressObjects = value;
    }

    public boolean isSetCompressObjects() {
        return (this.compressObjects!= null);
    }

}
